import {
  WifiConfProtocolBase,
  queryTokenStateAndBind,
  constants,
} from 'qcloud-iotexplorer-appdev-plugin-wificonf-core';

const { WifiConfErrorMsg, WifiConfStepCode } = constants;

/*
  该sdk提供两个方法
  1. 绘制二维码
  2. 轮询检查链接的状态
*/

export class QrCode extends WifiConfProtocolBase {
  // eslint-disable-next-line no-useless-constructor
  constructor(sdk, options) {
    super(sdk, options);
  }

  // 轮询检查设备的绑定状态
  async doBusiness() {
    try {
      const deviceInfo = await queryTokenStateAndBind({
        token: this.options.wifiConfToken,
        productId: '',
        deviceName: '',
        familyId: this.options.familyId,
        roomId: this.options.roomId,
        onProgress: (data) => {
          this.onProgress.call(this, data);
        },
        sdk: this.sdk,
        newTokenVersion: this.options.newTokenVersion,
      });
      this.onComplete(deviceInfo);
    } catch (error) {
      console.log(error);
      if (error && error.code in WifiConfErrorMsg) {
        error.uiMsg = WifiConfErrorMsg[error.code];
      }
      this.onProgress({
        code: WifiConfStepCode.WIFI_CONF_FAIL,
        detail: { error },
      });
      this.onError({ code: 'WIFI_CONF_FAIL', detail: { error } });
    }
  }
}
